@@ -61,7 +61,6 @@ import manimpango
 from manimpango import MarkupUtils, PangoUtils, TextSetting
 
 from ... import config, logger
-from ..._config.utils import ManimConfig
 from ...constants import *
 from ...mobject.geometry import Dot
 from ...mobject.svg.svg_mobject import SVGMobject
@@ -228,7 +227,7 @@ class CairoText(SVGMobject):
         if self.t2g:
             self.set_color_by_t2g()
         # anti-aliasing
-        if self.height is None and self.width is None:
+        if height is None and width is None:
             self.scale(TEXT_MOB_SCALE_FACTOR)
 
     def __repr__(self):
@@ -568,7 +567,7 @@ class Paragraph(VGroup):
             self[line_no].move_to(
                 np.array(
                     [
-                        self.get_right()[0] - self[line_no].get_width() / 2,
+                        self.get_right()[0] - self[line_no].width / 2,
                         self[line_no].get_center()[1],
                         0,
                     ]
@@ -578,7 +577,7 @@ class Paragraph(VGroup):
             self[line_no].move_to(
                 np.array(
                     [
-                        self.get_left()[0] + self[line_no].get_width() / 2,
+                        self.get_left()[0] + self[line_no].width / 2,
                         self[line_no].get_center()[1],
                         0,
                     ]
@@ -799,7 +798,7 @@ class Text(SVGMobject):
         if self.t2g:
             self.set_color_by_t2g()
         # anti-aliasing
-        if self.height is None and self.width is None:
+        if height is None and width is None:
             self.scale(TEXT_MOB_SCALE_FACTOR)
 
     def __repr__(self):
@@ -964,6 +963,9 @@ class Text(SVGMobject):
             self.text,
         )
 
+    def init_colors(self, propagate_colors=True):
+        SVGMobject.init_colors(self, propagate_colors=propagate_colors)
+
 
 class MarkupText(SVGMobject):
     r"""Display (non-LaTeX) text rendered using `Pango <https://pango.gnome.org/>`_.
@@ -977,28 +979,39 @@ class MarkupText(SVGMobject):
     - ``<tt>typewriter font</tt>``
     - ``<big>bigger font</big>`` and ``<small>smaller font</small>``
     - ``<sup>superscript</sup>`` and ``<sub>subscript</sub>``
-    - ``<span underline="double">double underline</span>``
+    - ``<span underline="double" underline_color="green">double underline</span>``
     - ``<span underline="error">error underline</span>``
+    - ``<span overline="single" overline_color="green">overline</span>``
+    - ``<span strikethrough="true" strikethrough_color="red">strikethrough</span>``
     - ``<span font_family="sans">temporary change of font</span>``
-    - ``<color col="RED">temporary change of color</color>``; colors can be specified as Manim constants like ``RED`` or ``YELLOW`` or as hex triples like ``#aabbaa``
-    - ``<gradient from="YELLOW" to="RED">temporary gradient</gradient>``; colors specified as above
+    - ``<span foreground="red">temporary change of color</span>``
+    - ``<span fgcolor="red">temporary change of color</span>``
+    - ``<gradient from="YELLOW" to="RED">temporary gradient</gradient>``
+
+    For ``<span>`` markup, colors can be specified either as hex triples like ``#aabbcc`` or as named CSS colors like ``AliceBlue``.
+    The ``<gradient>`` tag being handled by Manim rather than Pango, supports hex triplets or Manim constants like ``RED`` or ``RED_A``.
+    If you want to use Manim constants like ``RED_A`` together with ``<span>``,
+    you will need to use Python's f-String syntax as follows:
+    ``f'<span foreground="{RED_A}">here you go</span>'``
 
     If your text contains ligatures, the :class:`MarkupText` class may incorrectly determine
-    the first and last letter to be colored. This is due to the fact that e.g. ``fl``
+    the first and last letter when creating the gradient. This is due to the fact that e.g. ``fl``
     are two characters, but might be set as one single glyph, a ligature. If your language does
-    not depend on ligatures, consider setting ``disable_ligatures=True``. If you cannot
-    or do not want to do without ligatures, the ``gradient`` and ``color`` tag support
-    an optional attribute ``offset`` which can be used to compensate for that error.
-    Usage is as follows:
+    not depend on ligatures, consider setting ``disable_ligatures=True``. If you cannot or do
+    not want to do without ligatures, the ``gradient`` tag supports an optional attribute ``offset``
+    which can be used to compensate for that error. Usage is as follows:
 
-    - ``<color col="RED" offset="1">red text</color>`` to *start* coloring one letter earlier
-    - ``<color col="RED" offset=",1">red text</color>`` to *end* coloring one letter earlier
-    - ``<color col="RED" offset="2,1">red text</color>`` to *start* coloring two letters earlier and *end* one letter earlier
+    - ``<gradient from="RED" to="YELLOW" offset="1">example</gradient>`` to *start* the gradient one letter earlier
+    - ``<gradient from="RED" to="YELLOW" offset=",1">example</gradient>`` to *end* the gradient one letter earlier
+    - ``<gradient from="RED" to="YELLOW" offset="2,1">example</gradient>`` to *start* the gradient two letters earlier and *end* it one letter earlier
 
     Specifying a second offset may be necessary if the text to be colored does
     itself contain ligatures. The same can happen when using HTML entities for
     special chars.
 
+    When using ``underline``, ``overline`` or ``strikethrough`` together with ``<gradient>`` tags, you will also need to use the offset, because
+    underlines are additional paths in the final :class:`SVGMobject`, check out the corresponding example.
+
     Escaping of special characters: ``>`` *should* be written as ``&gt;`` whereas ``<`` and
     ``&`` *must* be written as ``&lt;`` and ``&amp;``.
 
@@ -1006,7 +1019,7 @@ class MarkupText(SVGMobject):
     corresponding documentation page:
     `Pango Markup <https://developer.gnome.org/pango/stable/pango-Markup.html>`_.
     Please be aware that not all features are supported by this class and that
-    the ``<color>`` and ``<gradient>`` tags mentioned above are not supported by Pango.
+    the ``<gradient>`` tag mentioned above is not supported by Pango.
 
     Parameters
     ----------
@@ -1061,7 +1074,7 @@ class MarkupText(SVGMobject):
         class ColorExample(Scene):
             def construct(self):
                 text1 = MarkupText(
-                    'all in red <color col="YELLOW">except this</color>', color=RED
+                    f'all in red <span fgcolor="{YELLOW}">except this</span>', color=RED
                 )
                 text2 = MarkupText("nice gradient", gradient=(BLUE, GREEN))
                 text3 = MarkupText(
@@ -1069,20 +1082,43 @@ class MarkupText(SVGMobject):
                     gradient=(BLUE, GREEN),
                 )
                 text4 = MarkupText(
-                    'fl ligature <color col="#00ff00">causing trouble</color> here'
+                    'fl ligature <gradient from="RED" to="YELLOW">causing trouble</gradient> here'
                 )
                 text5 = MarkupText(
-                    'fl ligature <color col="#00ff00" offset="1">defeated</color> with offset'
+                    'fl ligature <gradient from="RED" to="YELLOW" offset="1">defeated</gradient> with offset'
                 )
                 text6 = MarkupText(
-                    'fl ligature <color col="GREEN" offset="1">floating</color> inside'
+                    'fl ligature <gradient from="RED" to="YELLOW" offset="1">floating</gradient> inside'
                 )
                 text7 = MarkupText(
-                    'fl ligature <color col="GREEN" offset="1,1">floating</color> inside'
+                    'fl ligature <gradient from="RED" to="YELLOW" offset="1,1">floating</gradient> inside'
                 )
                 group = VGroup(text1, text2, text3, text4, text5, text6, text7).arrange(DOWN)
                 self.add(group)
 
+    .. manim:: UnderlineExample
+        :save_last_frame:
+
+        class UnderlineExample(Scene):
+            def construct(self):
+                text1 = MarkupText(
+                    '<span underline="double" underline_color="green">bla</span>'
+                )
+                text2 = MarkupText(
+                    '<span underline="single" underline_color="green">xxx</span><gradient from="#ffff00" to="RED">aabb</gradient>y'
+                )
+                text3 = MarkupText(
+                    '<span underline="single" underline_color="green">xxx</span><gradient from="#ffff00" to="RED" offset="-1">aabb</gradient>y'
+                )
+                text4 = MarkupText(
+                    '<span underline="double" underline_color="green">xxx</span><gradient from="#ffff00" to="RED">aabb</gradient>y'
+                )
+                text5 = MarkupText(
+                    '<span underline="double" underline_color="green">xxx</span><gradient from="#ffff00" to="RED" offset="-2">aabb</gradient>y'
+                )
+                group = VGroup(text1, text2, text3, text4, text5).arrange(DOWN)
+                self.add(group)
+
     .. manim:: FontExample
         :save_last_frame:
 
@@ -1104,7 +1140,7 @@ class MarkupText(SVGMobject):
 
         class NewlineExample(Scene):
             def construct(self):
-                text = MarkupText('foooo<color col="RED">oo\nbaa</color>aar')
+                text = MarkupText('foooo<span foreground="red">oo\nbaa</span>aar')
                 self.add(text)
 
     .. manim:: NoLigaturesExample
@@ -1112,8 +1148,8 @@ class MarkupText(SVGMobject):
 
         class NoLigaturesExample(Scene):
             def construct(self):
-                text1 = MarkupText('fl<color col="RED">oat</color>ing')
-                text2 = MarkupText('fl<color col="RED">oat</color>ing', disable_ligatures=True)
+                text1 = MarkupText('fl<gradient from="RED" to="GREEN">oat</gradient>ing')
+                text2 = MarkupText('fl<gradient from="RED" to="GREEN">oat</gradient>ing', disable_ligatures=True)
                 group = VGroup(text1, text2).arrange(DOWN)
                 self.add(group)
 
@@ -1128,7 +1164,7 @@ class MarkupText(SVGMobject):
             def construct(self):
                 morning = MarkupText("வணக்கம்", font="sans-serif")
                 chin = MarkupText(
-                    '見 角 言 谷  辛 <color col="BLUE">辰 辵 邑</color> 酉 釆 里!'
+                    '見 角 言 谷  辛 <span fgcolor="blue">辰 辵 邑</span> 酉 釆 里!'
                 )  # works as in ``Text``.
                 mess = MarkupText("Multi-Language", style=BOLD)
                 russ = MarkupText("Здравствуйте मस नम म ", font="sans-serif")
@@ -1169,6 +1205,7 @@ class MarkupText(SVGMobject):
         **kwargs,
     ):
         self.text = text
+        self.color = color
         self.size = size
         self.line_spacing = line_spacing
         self.font = font
@@ -1184,6 +1221,10 @@ class MarkupText(SVGMobject):
             text_without_tabs = text.replace("\t", " " * self.tab_width)
 
         colormap = self.extract_color_tags()
+        if len(colormap) > 0:
+            logger.warning(
+                f'Using <color> tags in MarkupText is deprecated. Please use <span foreground="..."> instead.'
+            )
         gradientmap = self.extract_gradient_tags()
 
         if not MarkupUtils.validate(self.text):
@@ -1203,7 +1244,6 @@ class MarkupText(SVGMobject):
         SVGMobject.__init__(
             self,
             file_name,
-            color=color,
             fill_opacity=fill_opacity,
             stroke_width=stroke_width,
             height=height,
@@ -1252,13 +1292,13 @@ class MarkupText(SVGMobject):
                 *(self._parse_color(grad["from"]), self._parse_color(grad["to"]))
             )
         # anti-aliasing
-        if self.height is None and self.width is None:
+        if height is None and width is None:
             self.scale(TEXT_MOB_SCALE_FACTOR)
 
     def text2hash(self):
         """Generates ``sha256`` hash for file name."""
         settings = (
-            "MARKUPPANGO" + self.font + self.slant + self.weight
+            "MARKUPPANGO" + self.font + self.slant + self.weight + self.color
         )  # to differentiate from classical Pango Text
         settings += str(self.line_spacing) + str(self.size)
         settings += str(self.disable_ligatures)
@@ -1282,7 +1322,7 @@ class MarkupText(SVGMobject):
 
         logger.debug(f"Setting Text {self.text}")
         return MarkupUtils.text2svg(
-            self.text,
+            f'<span foreground="{self.color}">{self.text}</span>',
             self.font,
             self.slant,
             self.weight,
@@ -1358,6 +1398,9 @@ class MarkupText(SVGMobject):
         with a custom color.
 
         Removes the ``<color>`` tag, as it is not part of Pango's markup and would cause an error.
+
+        Note: Using the ``<color>`` tags is deprecated. As soon as the legacy syntax is gone, this function
+        will be removed.
         """
         tags = re.finditer(
             '<color\s+col="([^"]+)"(\s+offset="([^"]+)")?>(.+?)</color>',
@@ -1429,8 +1472,8 @@ def register_font(font_file: typing.Union[str, Path]):
 
     .. important ::
 
-        This method isn't available for macOS. Using this
-        method on macOS will raise an :class:`AttributeError`.
+        This method is available for macOS for ``ManimPango>=v0.2.3``. Using this
+        method with previous releases will raise an :class:`AttributeError` on macOS.
     """
 
     input_folder = Path(config.input_file).parent.resolve()
