@@ -15,6 +15,8 @@ import time
 import subprocess as sp
 from pathlib import Path
 
+from manim import __version__
+
 
 def add_extension_if_not_present(file_name, extension):
     if file_name.suffix != extension:
@@ -23,6 +25,12 @@ def add_extension_if_not_present(file_name, extension):
         return file_name
 
 
+def add_version_before_extension(file_name):
+    file_name = Path(file_name)
+    path, name, suffix = file_name.parent, file_name.stem, file_name.suffix
+    return Path(path, f"{name}_ManimCE_v{__version__}{suffix}")
+
+
 def guarantee_existence(path):
     if not os.path.exists(path):
         os.makedirs(path)
